summaryrefslogtreecommitdiffstats
path: root/src/bookmarkselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/bookmarkselector.h')
-rw-r--r--src/bookmarkselector.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/src/bookmarkselector.h b/src/bookmarkselector.h
index 9bede96..d56aec2 100644
--- a/src/bookmarkselector.h
+++ b/src/bookmarkselector.h
@@ -25,7 +25,7 @@
#include <urlbutton.h>
class URLNavigator;
-class QPopupMenu;
+class TQPopupMenu;
class KURL;
/**
@@ -40,21 +40,22 @@ class KURL;
class BookmarkSelector : public URLButton
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @param parent Parent widget where the bookmark selector
* is embedded into.
*/
- BookmarkSelector(URLNavigator* parent);
+ BookmarkSelector(URLNavigator* tqparent);
virtual ~BookmarkSelector();
/**
* Updates the selection dependent from the given URL \a url. The
* URL must not match exactly to one of the available bookmarks:
* The bookmark which is equal to the URL or at least is a parent URL
* is selected. If there are more than one possible parent URL candidates,
* the bookmark which covers the bigger range of the URL is selected.
*/
void updateSelection(const KURL& url);
@@ -80,7 +81,7 @@ protected:
* Draws the icon of the selected URL as content of the URL
* selector.
*/
- virtual void drawButton(QPainter* painter);
+ virtual void drawButton(TQPainter* painter);
private slots:
/**
@@ -92,7 +93,7 @@ private slots:
private:
int m_selectedIndex;
- QPopupMenu* m_bookmarksMenu;
+ TQPopupMenu* m_bookmarksMenu;
};
#endif
@@ -40,21 +40,22 @@ class KURL;
public:
/**
- * @param parent Parent widget where the bookmark selector
+ * @param tqparent Parent widget where the bookmark selector
* is embedded into.
*/
@@ -40,21 +40,22 @@ class KURL;
* Updates the selection dependent from the given URL \a url. The
* URL must not match exactly to one of the available bookmarks:
- * The bookmark which is equal to the URL or at least is a parent URL
- * is selected. If there are more than one possible parent URL candidates,
+ * The bookmark which is equal to the URL or at least is a tqparent URL
+ * is selected. If there are more than one possible tqparent URL candidates,
* the bookmark which covers the bigger range of the URL is selected.
*/